@@ -21,17 +21,11 @@ void managepresets::readpresets()
     ui->presetslist->addItems(presets);
 }
 
-void managepresets::on_presetslist_currentIndexChanged(int index)
+void managepresets::on_presetslist_currentRowChanged(int currentRow)
 {
-
-        if (ui->presetslist->currentIndex() > 2) {
-        ui->delbutton->setEnabled(true);
-        } else {
-        ui->delbutton->setDisabled(true);
-        }
-
-        if (!ui->presetslist->currentIndex() == 0) {
-            ui->loadbutton->setEnabled(true);
-        }
-
+    if (ui->presetslist->currentRow() > 1) {
+    ui->delbutton->setEnabled(true);
+    } else {
+    ui->delbutton->setDisabled(true);
+    }
 }
