@@ -7,6 +7,26 @@
         <source>Selected theme is currently in use!</source>
         <translation>选定的主题是目前正在使用!</translation>
     </message>
+    <message>
+        <source>Export theme</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Import theme</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Exporting theme</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Select .tgz file to import</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Importing theme</source>
+        <translation type="unfinished"></translation>
+    </message>
     <message>
         <source>You can&apos;t delete a theme that&apos;s currently active.</source>
         <translation>无法删除当前活动的主题.</translation>
