@@ -8,6 +8,26 @@
         <source>Theme Customizer</source>
         <translation>Theme Customizer</translation>
     </message>
+    <message>
+        <source>Export theme</source>
+        <translation>Vie teema</translation>
+    </message>
+    <message>
+        <source>Import theme</source>
+        <translation>Tuo teema</translation>
+    </message>
+    <message>
+        <source>Exporting theme</source>
+        <translation>Viedään teemaa</translation>
+    </message>
+    <message>
+        <source>Select .tgz file to import</source>
+        <translation>Valitse .tgz tiedosto tuotavaksi</translation>
+    </message>
+    <message>
+        <source>Importing theme</source>
+        <translation>Tuodaan teemaa</translation>
+    </message>
     <message>
         <location filename="mainwindow.ui" line="0"/>
         <source>Restore theme files</source>
@@ -66,7 +86,7 @@
     <message>
         <location filename="mainwindow.cpp" line="0"/>
         <source>Saving new theme...</source>
-        <translation type="unfinished">Tallennetaan uutta teemaa...</translation>
+        <translation>Tallennetaan uutta teemaa...</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="0"/>
