@@ -8,6 +8,26 @@
         <source>Theme Customizer</source>
         <translation>Theme Customizer</translation>
     </message>
+    <message>
+        <source>Export theme</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Import theme</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Exporting theme</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Select .tgz file to import</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Importing theme</source>
+        <translation type="unfinished"></translation>
+    </message>
     <message>
         <location filename="mainwindow.ui" line="0"/>
         <source>Restore theme files</source>
